==> 0.0.1.tar.gz: android/src/main/kotlin/com/tpl/tplmapsflutter/tplmapsflutterplugin/TplmapsflutterpluginPlugin.kt <==
package com.tpl.tplmapsflutter.tplmapsflutterplugin

import androidx.annotation.NonNull
import com.tpl.tplmapsflutter.TPLMapViewFactory
import io.flutter.embedding.android.FlutterActivity
import io.flutter.embedding.engine.FlutterEngine

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** TplmapsflutterpluginPlugin */
class TplmapsflutterpluginPlugin : FlutterPlugin, MethodCallHandler, FlutterActivity() {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
//        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "tplmapsflutterplugin")
//        channel.setMethodCallHandler(this)

        flutterPluginBinding
            .getPlatformViewRegistry()
            .registerViewFactory("map", TPLMapViewFactory())
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
//        if (call.method == "getPlatformVersion") {
//            result.success("Android ${android.os.Build.VERSION.RELEASE}")
//        } else {
//            result.notImplemented()
//        }
    }
//
    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
       // channel.setMethodCallHandler(null)
    }


}

==> 0.0.3.tar.gz: android/src/main/kotlin/com/tpl/tplmapsflutter/tplmapsflutterplugin/TplmapsflutterpluginPlugin.kt <==
package com.tpl.tplmapsflutter.tplmapsflutterplugin

import androidx.annotation.NonNull
import com.tpl.tplmapsflutter.TPLMapViewFactory
import io.flutter.embedding.android.FlutterActivity
import io.flutter.embedding.engine.FlutterEngine

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** TplmapsflutterpluginPlugin */
class TplmapsflutterpluginPlugin : FlutterPlugin, MethodCallHandler, FlutterActivity() {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
//        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "tplmapsflutterplugin")
//        channel.setMethodCallHandler(this)


        flutterPluginBinding
            .getPlatformViewRegistry()
            .registerViewFactory("map", TPLMapViewFactory(flutterPluginBinding.binaryMessenger))
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "getPlatformVersion") {
            result.success("Android ${android.os.Build.VERSION.RELEASE}")
        } else {
            result.notImplemented()
        }
    }
//
    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
       // channel.setMethodCallHandler(null)
    }


}
